
# Slot: name




URI: [nwb_schema_language:name](https://w3id.org/p2p_ld/nwb-schema-language/name)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children

 *  [Attribute➞name](Attribute_name.md)
 *  [CompoundDtype➞name](CompoundDtype_name.md)
 *  [Namespace➞name](Namespace_name.md)

## Used by

 * [Dataset](Dataset.md)
 * [Group](Group.md)
 * [Link](Link.md)
